tag

package
v0.5.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 16, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(name, description string, opts ...Option) *base.Tag

New creates a tag definition with the provided name, description, and options.

Types

type Option

type Option func(*base.Tag)

Option configures a tag entry.

func ExternalDocs

func ExternalDocs(url, description string) Option

ExternalDocs attaches external documentation to the tag.

func Kind

func Kind(kind string) Option

Kind sets the tag kind (OpenAPI 3.2+).

func Parent

func Parent(parent string) Option

Parent sets the parent tag name (OpenAPI 3.2+).

func Summary

func Summary(summary string) Option

Summary sets a short summary for the tag (OpenAPI 3.2+).

Jump to